from __future__ import unicode_literals
from django.utils.encoding import python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _
from django.db import models
from mptt.models import MPTTModel, TreeForeignKey

@python_2_unicode_compatible
class Menu(MPTTModel):
    TYPE_CHOICES = (
        ('view', _('view menu')),
        ('click', _('click menu')),
    )
    name = models.CharField(_('name'), max_length=100)
    parent = TreeForeignKey('self', null=True, blank=True, db_index=True,\
                            related_name='children', verbose_name=_('parent'))
    type = models.CharField(_('type'), max_length=100, choices=TYPE_CHOICES,\
                            blank=True, null=True)
    value = models.CharField(_('value'), max_length=200, blank=True, null=True)

    def __str__(self):
        return self.name

    class MPTTMeta:
        order_insertion_by = ['name']

    class Meta(object):
        verbose_name = _('wechat menu')
        verbose_name_plural = _('wechat menu')



import json
from wechat.api import Base
from .models import Menu as MenuModel

class Menu(Base):
    """ Wechat Menu Api """
    def sync_menu(self):
        menu = self.get_menu()
        url = self.get_url(
            'menu/create',
            {'access_token': self.get_token()}
        )
        result = self.get_data(url, menu)
        return result


    def get_menu(self):
        top = MenuModel.objects.root_nodes()
        button = {'button':[]}
        for i, item in enumerate(top):
            children = item.get_children()
            if children:
                sub_button = []
                for i, chil_item in enumerate(children):
                    sub_button.append(self.get_child_menu(chil_item))
                button['button'].append({
                    'name': item.name,
                    'sub_button': sub_button
                })
            else:
                button['button'].append(self.get_child_menu(item))

        button = json.dumps(button, ensure_ascii=False)
        button = button.encode('utf8')
        return button


    def get_child_menu(self, menu):
        if menu.type == 'view':
            button = {
                'name': menu.name,
                'type': menu.type,
                'url': menu.value,
            }
        elif menu.type == 'click':
            button = {
                'name': menu.name,
                'type': menu.type,
                'key': menu.value,
            }
        else:
            button = {
                'name': menu.name,
            }
        return button



from django.utils.translation import ugettext_lazy as _
from django.contrib import admin, messages
from mptt.admin import DraggableMPTTAdmin
from django.http import HttpResponseRedirect
from django.conf.urls import url
from .models import Menu
from .api import Menu as MenuApi


class MenuAdmin(DraggableMPTTAdmin):
    list_display = ('tree_actions', 'indented_title', 'type', 'value')
    list_display_links = ('indented_title',)

    def get_urls(self):
        urls = super(MenuAdmin, self).get_urls()
        return [url(r'^sync/$', self.sync_menu),] + urls

    def sync_menu(self, request):
        wx = MenuApi()
        result = wx.sync_menu()
        if result['errcode'] == 0:
            messages.add_message(request, messages.SUCCESS, _('sync success'))
        else:
            messages.add_message(request, messages.ERROR, _('sync error'))
        return HttpResponseRedirect('/admin/wechat_menu/menu/')


admin.site.register(Menu, MenuAdmin)



from django.test import TestCase
from .models import Menu as MenuModel
from .api import Menu as MenuApi

class Menu(TestCase):
    def setUp(self):
        main1 = MenuModel.objects.create(name="main1")
        MenuModel.objects.create(name="chil1",parent=main1,type='view',value='hh')
        MenuModel.objects.create(name="chil2",parent=main1,type='click',value='hh')
        main2 = MenuModel.objects.create(name="main2")

    def test_menu_list(self):
        wx = MenuApi()
        data = wx.get_menu()
        print(data)
